@@ -29,18 +29,21 @@ pip install cloudcomponents.cdk-stripe-webhook
 ### EventBus Producer
 
 ```python
-import { StringParameter } from '@aws-cdk/aws-ssm';
-import { Construct, Stack, StackProps } from '@aws-cdk/core';
 import { SecretKey, SecretKeyStore } from '@cloudcomponents/cdk-secret-key';
 import { StripeWebhook, StripeEventBusProducer } from '@cloudcomponents/cdk-stripe-webhook';
+import { Stack, StackProps, aws_ssm } from 'aws-cdk-lib';
+import { Construct } from 'constructs';
 
-export class StripeWebhookStack extends Stack {
+export class StripeWebhookEventBusStack extends Stack {
   constructor(scope: Construct, id: string, props?: StackProps) {
     super(scope, id, props);
 
-    const secretKey = SecretKey.fromPlainText(process.env.SECRET_KEY as string);
+    if (typeof process.env.SECRET_KEY === 'undefined') {
+      throw new Error('environment variable SECRET_KEY undefined');
+    }
+    const secretKey = SecretKey.fromPlainText(process.env.SECRET_KEY);
 
-    const endpointSecretParameter = StringParameter.fromSecureStringParameterAttributes(this, 'Param', {
+    const endpointSecretParameter = aws_ssm.StringParameter.fromSecureStringParameterAttributes(this, 'Param', {
       parameterName: 'stripe',
       version: 1,
     });
@@ -68,18 +71,21 @@ export class StripeWebhookStack extends Stack {
 ### Custom Handler
 
 ```python
-import { RestApi } from '@aws-cdk/aws-apigateway';
-import { Construct, Stack, StackProps } from '@aws-cdk/core';
 import { SecretKey } from '@cloudcomponents/cdk-secret-key';
 import { StripeWebhook } from '@cloudcomponents/cdk-stripe-webhook';
+import { Stack, StackProps, aws_apigateway } from 'aws-cdk-lib';
+import { Construct } from 'constructs';
 export class StripeWebhookStack extends Stack {
   constructor(scope: Construct, id: string, props?: StackProps) {
     super(scope, id, props);
 
-    const api = new RestApi(this, 'Endpoint');
+    const api = new aws_apigateway.RestApi(this, 'Endpoint');
     api.root.addMethod('POST');
 
-    const secretKey = SecretKey.fromPlainText(process.env.SECRET_KEY as string);
+    if (typeof process.env.SECRET_KEY === 'undefined') {
+      throw new Error('environment variable SECRET_KEY undefined');
+    }
+    const secretKey = SecretKey.fromPlainText(process.env.SECRET_KEY);
 
     const events = ['charge.failed', 'charge.succeeded'];
 
@@ -118,18 +124,18 @@ import typing_extensions
 from ._jsii import *
 
 import aws_cdk.aws_events
-import aws_cdk.core
 import cloudcomponents.cdk_secret_key
+import constructs
 
 
 class StripeEventBusProducer(
-    aws_cdk.core.Construct,
+    constructs.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cloudcomponents/cdk-stripe-webhook.StripeEventBusProducer",
 ):
     def __init__(
         self,
-        scope: aws_cdk.core.Construct,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         endpoint_secret: cloudcomponents.cdk_secret_key.SecretKey,
@@ -255,13 +261,13 @@ class StripeEventBusProducerProps:
 
 
 class StripeWebhook(
-    aws_cdk.core.Construct,
+    constructs.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cloudcomponents/cdk-stripe-webhook.StripeWebhook",
 ):
     def __init__(
         self,
-        scope: aws_cdk.core.Construct,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         events: typing.Sequence[builtins.str],
